aboutsummaryrefslogtreecommitdiffstats
path: root/test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh
diff options
context:
space:
mode:
authorRemigiusz Janeczek <remigiusz.janeczek@nokia.com>2020-07-27 13:42:09 +0200
committerBartek Grzybowski <b.grzybowski@partner.samsung.com>2020-07-29 09:00:45 +0000
commit7b4d5778c13818b871a5fe5aaf249480981ac15d (patch)
tree528f085633262f6b8333da40aaaa2864f74f8acd /test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh
parent30e199a70b32a6256c2a148eec870800ef1fbefc (diff)
Adjust DFC test files to use FTPES instead of FTPS
DFC doesn't support FTPS protocol. FTPS is treated exactly like FTPES and soon DFC won't accept file locations starting with "ftps://". Fix mr-sim.py lint issues Issue-ID: DCAEGEN2-2367 Signed-off-by: Remigiusz Janeczek <remigiusz.janeczek@nokia.com> Change-Id: Idab56aab3bdb6734a04bfc9c9212f2ea800d0d74
Diffstat (limited to 'test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh')
-rwxr-xr-xtest/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh b/test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh
index 666e14a8e..11e4c0e11 100755
--- a/test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh
+++ b/test/mocks/datafilecollector-testharness/simulator-group/prepare-images.sh
@@ -12,8 +12,8 @@ cd ../dr-sim
docker build -t drsim_common:latest .
-#Build image for ftps server
-cd ../ftps-sftp-server
+#Build image for ftpes server
+cd ../ftpes-sftp-server
-docker build -t ftps_vsftpd:latest -f Dockerfile-ftps .
+docker build -t ftpes_vsftpd:latest -f Dockerfile-ftpes .